@@ -8,68 +8,48 @@
 # @Software     : PyCharm
 # @Description  : todo: 增加nn模型
 
+from meutils.pipe import *
+from sklearn.metrics import roc_auc_score
+from sklearn.model_selection import train_test_split, StratifiedKFold
 
+# ME
 from aizoo.base import OOF
 
 
-class LGBMClassifier(OOF):
+
+
+class LGBMOOF(OOF):
 
     def fit_predict(self, X_train, y_train, X_valid, y_valid, X_test, **kwargs):
         import lightgbm as lgb
 
-        clf = lgb.LGBMClassifier()
-        if self.params is not None:
-            clf.set_params(**self.params)
+        estimator = lgb.__getattribute__(f'LGBM{self.task}')()  # 实例
+        estimator.set_params(**self.params)
 
         eval_set = [(X_train, y_train), (X_valid, y_valid)]
         fit_params = dict(
             eval_set=eval_set,
             eval_metric=None,
-            eval_names=('Train', 'Valid'),
+            eval_names=('Train🔥', 'Valid'),
             verbose=100,
             early_stopping_rounds=100,
         )
-        self.clf = clf.fit(
-            X_train, y_train,
-            **{**fit_params, **self.fit_params}  # fit_params
-        )
 
-        if hasattr(clf, 'predict_proba'):
-            return clf.predict_proba(X_valid), clf.predict_proba(X_test)
-        else:
-            return clf.predict(X_valid), clf.predict(X_test)
-
-
-class LGBMRegressor(OOF):
-
-    def fit_predict(self, X_train, y_train, X_valid, y_valid, X_test, *kwargs):
-        import lightgbm as lgb
-
-        clf = lgb.LGBMRegressor()
-        if self.params is not None:
-            clf.set_params(**self.params)
-
-        eval_set = [(X_train, y_train), (X_valid, y_valid)]
-        fit_params = dict(
-            eval_set=eval_set,
-            eval_metric=None,
-            eval_names=('Train', 'Valid'),
-            verbose=100,
-            early_stopping_rounds=100,
-        )
         if self.weight_func is not None:
             fit_params['sample_weight'] = self.weight_func(y_train)
             fit_params['eval_sample_weight'] = [self.weight_func(y_valid)]  # 列表
 
-        self.clf = clf.fit(
+        estimator.fit(
             X_train, y_train,
             **{**fit_params, **self.fit_params}  # fit_params
         )
 
-        if hasattr(clf, 'predict_proba'):
-            return clf.predict_proba(X_valid), clf.predict_proba(X_test)
+        self._estimators.append(estimator)
+
+        if hasattr(estimator, 'predict_proba'):
+            return estimator.predict_proba(X_valid), estimator.predict_proba(X_test)
         else:
-            return clf.predict(X_valid), clf.predict(X_test)
+            return estimator.predict(X_valid), estimator.predict(X_test)
 
 
 class XGBClassifier(OOF):
@@ -225,17 +205,21 @@ class TabNetRegressor(OOF):
 
 
 if __name__ == '__main__':
+    import shap
+
+    print(shap.__version__)
     from sklearn.metrics import r2_score, roc_auc_score
     from sklearn.datasets import make_regression, make_classification
 
-    # for Model in [TabNetClassifier, CatBoostClassifier, LGBMClassifier, XGBClassifier]:
-    #     X, y = make_classification(n_samples=1000)
-    #     oof = Model()
-    #     oof.run(X, y, feval=roc_auc_score, cv=5)
-    #     break
+    for Model in [LGBMOOF, TabNetRegressor, CatBoostRegressor, XGBRegressor]:
+        X, y = make_classification(n_samples=1000)
+        oof = Model(importance_type='shap')
+        oof.fit(X, y, feval=roc_auc_score, cv=5)
 
-    for Model in [LGBMRegressor, TabNetRegressor, CatBoostRegressor, LGBMRegressor, XGBRegressor]:
-        X, y = make_regression(n_samples=1000)
-        oof = Model(weight_func=lambda w: 1 / (w + 1))
-        oof.run(X, y, feval=r2_score, cv=5)
         break
+
+    # for Model in [LGBMOOF, TabNetRegressor, CatBoostRegressor, , XGBRegressor]:
+    #     X, y = make_regression(n_samples=1000)
+    #     oof = Model(weight_func=lambda w: 1 / (w + 1))
+    #     oof.run(X, y, feval=r2_score, cv=5)
+    #     break
